@@ -15,10 +15,10 @@
 #include "config.h"
 #include "../tools/openFile.h"
 #include <cgraph/cgraph.h>
-#include <cgraph/agxbuf.h>
 #include <cgraph/ingraphs.h>
 #include <common/pointset.h>
 #include <getopt.h>
+#include <util/agxbuf.h>
 #include <util/alloc.h>
 #include <util/exit.h>
 #include <util/startswith.h>
