@@ -15,17 +15,17 @@
  *************************************************************************/
 
 #include <assert.h>
-#include <cgraph/alloc.h>
-#include <cgraph/exit.h>
-#include <cgraph/overflow.h>
-#include <cgraph/prisize_t.h>
-#include <cgraph/queue.h>
+#include <cgraph/list.h>
 #include <common/render.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stddef.h>
 #include <stdint.h>
 #include <stdio.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/overflow.h>
+#include <util/prisize_t.h>
 #include <util/streq.h>
 
 static void dfs_cutval(node_t * v, edge_t * par);
@@ -143,6 +143,8 @@ static void exchange_tree_edges(edge_t * e, edge_t * f)
     ND_tree_in(n).list[ND_tree_in(n).size] = NULL;
 }
 
+DEFINE_LIST(node_queue, node_t *)
+
 static
 void init_rank(void)
 {
@@ -150,22 +152,24 @@ void init_rank(void)
     node_t *v;
     edge_t *e;
 
-    queue_t Q = queue_new(N_nodes);
+    node_queue_t Q = {0};
+    node_queue_reserve(&Q, N_nodes);
     size_t ctr = 0;
 
     for (v = GD_nlist(G); v; v = ND_next(v)) {
 	if (ND_priority(v) == 0)
-	    queue_push(&Q, v);
+	    node_queue_push_back(&Q, v);
     }
 
-    while ((v = queue_pop(&Q))) {
+    while (!node_queue_is_empty(&Q)) {
+	v = node_queue_pop_front(&Q);
 	ND_rank(v) = 0;
 	ctr++;
 	for (i = 0; (e = ND_in(v).list[i]); i++)
 	    ND_rank(v) = MAX(ND_rank(v), ND_rank(agtail(e)) + ED_minlen(e));
 	for (i = 0; (e = ND_out(v).list[i]); i++) {
 	    if (--ND_priority(aghead(e)) <= 0)
-		queue_push(&Q, aghead(e));
+		node_queue_push_back(&Q, aghead(e));
 	}
     }
     if (ctr != N_nodes) {
@@ -174,7 +178,7 @@ void init_rank(void)
 	    if (ND_priority(v))
 		agerr(AGPREV, "\t%s %d\n", agnameof(v), ND_priority(v));
     }
-    queue_free(&Q);
+    node_queue_free(&Q);
 }
 
 static edge_t *leave_edge(void)
@@ -524,7 +528,7 @@ subtree_t *merge_trees(Agedge_t *e)   /* entering tree edge */
 
 /* Construct initial tight tree. Graph must be connected, feasible.
  * Adjust ND_rank(v) as needed.  add_tree_edge() on tight tree edges.
- * trees are basically lists of nodes stored in nodequeues.
+ * trees are basically lists of nodes stored in `node_queue_t`s.
  * Return 1 if input graph is not connected; 0 on success.
  */
 static
