@@ -17,7 +17,6 @@
  */
 
 #include <assert.h>
-#include <cgraph/agxbuf.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/gv_math.h>
 #include <cgraph/list.h>
@@ -26,6 +25,7 @@
 #include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
+#include <util/agxbuf.h>
 #include <util/alloc.h>
 #include <util/exit.h>
 #include <util/streq.h>
