@@ -33,12 +33,12 @@
 #include <common/render.h>
 #include <common/utils.h>
 #include <neatogen/sgd.h>
-#include <cgraph/agxbuf.h>
 #include <cgraph/cgraph.h>
 #include <cgraph/gv_ctype.h>
 #include <float.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/agxbuf.h>
 #include <util/alloc.h>
 #include <util/bitarray.h>
 #include <util/prisize_t.h>
