@@ -578,8 +578,7 @@ void makeSpline(edge_t *e, Ppoly_t **obs, int npoly, bool chkPts) {
   /* True if either head or tail has a port on its boundary */
 #define BOUNDARY_PORT(e) ((ED_tail_port(e).side)||(ED_head_port(e).side))
 
-/* _spline_edges:
- * Basic default routine for creating edges.
+/* Basic default routine for creating edges.
  * If splines are requested, we construct the obstacles.
  * If not, or nodes overlap, the function reverts to line segments.
  * NOTE: intra-cluster edges are not constrained to
@@ -588,8 +587,7 @@ void makeSpline(edge_t *e, Ppoly_t **obs, int npoly, bool chkPts) {
  * If Nop > 1 and the spline exists, it is just copied.
  * NOTE: if edgetype = EDGETYPE_NONE, we shouldn't be here.
  */
-static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
-{
+static int spline_edges_(graph_t *g, expand_t *pmargin, int edgetype) {
     node_t *n;
     edge_t *e;
     edge_t *e0;
@@ -781,7 +779,7 @@ splineEdges(graph_t * g, int (*edgefn) (graph_t *, expand_t*, int),
  */
 int spline_edges1(graph_t * g, int edgetype)
 {
-    return splineEdges(g, _spline_edges, edgetype);
+  return splineEdges(g, spline_edges_, edgetype);
 }
 
 /* spline_edges0:
@@ -1046,8 +1044,8 @@ static bool _neato_set_aspect(graph_t * g)
 	    /* fill is weird because both X and Y can stretch */
 	    if (GD_drawing(g)->size.x <= 0)
 		return translated;
-	    xf = (double) GD_drawing(g)->size.x / GD_bb(g).UR.x;
-	    yf = (double) GD_drawing(g)->size.y / GD_bb(g).UR.y;
+	    xf = GD_drawing(g)->size.x / GD_bb(g).UR.x;
+	    yf = GD_drawing(g)->size.y / GD_bb(g).UR.y;
 	    /* handle case where one or more dimensions is too big */
 	    if (xf < 1.0 || yf < 1.0) {
 		if (xf < yf) {
@@ -1061,8 +1059,8 @@ static bool _neato_set_aspect(graph_t * g)
 	} else if (GD_drawing(g)->ratio_kind == R_EXPAND) {
 	    if (GD_drawing(g)->size.x <= 0)
 		return translated;
-	    xf = (double) GD_drawing(g)->size.x / GD_bb(g).UR.x;
-	    yf = (double) GD_drawing(g)->size.y / GD_bb(g).UR.y;
+	    xf = GD_drawing(g)->size.x / GD_bb(g).UR.x;
+	    yf = GD_drawing(g)->size.y / GD_bb(g).UR.y;
 	    if (xf > 1.0 && yf > 1.0) {
 		double scale = fmin(xf, yf);
 		xf = yf = scale;
